﻿using System;
using System.Collections.Generic;
using System.Windows.Forms;
using Text_File_Spawn_Utility.Properties;

namespace Text_File_Spawn_Utility
{
    public partial class Form1 : Form
    {
        #region Variables

        private string inputFile;
        private string outputFolder;
        private FileNameGeneratorType generatorType = FileNameGeneratorType.DateTimeMilliseconds;

        private char delimiter = '*';
        private string fileNameKeyword;

        #endregion

        public Form1()
        {
            InitializeComponent();
        }

        #region Events

        private void LoadFile_Click(object sender, EventArgs e)
        {
            openFileDialog1.Filter = "txt|*.txt";
            if (openFileDialog1.ShowDialog() == System.Windows.Forms.DialogResult.OK)
            {
                inputFile = openFileDialog1.FileName;
                InputFileTextBox.Text = inputFile;
            }
        }

        private void OutputFolder_Click(object sender, EventArgs e)
        {
            if (folderBrowserDialog1.ShowDialog() == System.Windows.Forms.DialogResult.OK)
            {
                outputFolder = folderBrowserDialog1.SelectedPath;
                OutputFolderTextBox.Text = outputFolder;
            }
        }

        private void SpawnButton_Click(object sender, EventArgs e)
        {
            if (InputFileTextBox.Text.Length > 0 
                && OutputFolderTextBox.Text.Length > 0 
                && DelimiterCharacterTextBox.Text.Length == 1 
                && Helpers.DelimiterIsValid(delimiter))
            {
                if (generatorType == FileNameGeneratorType.KeywordSequential && KeywordTextBox.Text.Length == 0)
                    return;

                fileNameKeyword = KeywordTextBox.Text;
                delimiter = DelimiterCharacterTextBox.Text[0];

                IList<string> spawnFiles = TextFile.LoadTextFile(inputFile, delimiter);

                // write files to output folder
                TextFile.CreateFiles(outputFolder, spawnFiles, generatorType, fileNameKeyword);
            }
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            // load settings
            if (!char.IsWhiteSpace(Settings.Default.Delimiter))
            {
                delimiter = Settings.Default.Delimiter;
            }

            inputFile = Settings.Default.FileName;
            outputFolder = Settings.Default.OutputFolder;
            fileNameKeyword = Settings.Default.Keyword;

            FileNameGeneratorType generatorTypeTemp;
            if (Enum.TryParse<FileNameGeneratorType>(Settings.Default.FileNameGeneratorType, out generatorTypeTemp))
            {
                generatorType = generatorTypeTemp;
            }

            switch (generatorType)
            {
                case FileNameGeneratorType.DateTimeMilliseconds:
                    DateTimeMillisecondsRadioButton.Checked = true;
                    break;
                case FileNameGeneratorType.KeywordSequential:
                    KeywordSequentialRadioButton.Checked = true;
                    break;
                default:
                    break;
            }

            InputFileTextBox.Text = inputFile;
            OutputFolderTextBox.Text = outputFolder;
            KeywordTextBox.Text = fileNameKeyword;
            DelimiterCharacterTextBox.Text = delimiter.ToString();
        }

        private void Form1_FormClosing(object sender, FormClosingEventArgs e)
        {
            // save settings
            if (DelimiterCharacterTextBox.Text.Length == 1)
            {
                Settings.Default.Delimiter = DelimiterCharacterTextBox.Text[0];
            }

            Settings.Default.FileName = inputFile;
            Settings.Default.OutputFolder = outputFolder;
            Settings.Default.FileNameGeneratorType = generatorType.ToString();
            Settings.Default.Keyword = fileNameKeyword;
            Settings.Default.Save();
        }

        private void DateTimeMillisecondsRadioButton_CheckedChanged(object sender, EventArgs e)
        {
            generatorType = FileNameGeneratorType.DateTimeMilliseconds;
            KeywordTextBox.Visible = false;
        }

        private void KeywordSequentialRadioButton_CheckedChanged(object sender, EventArgs e)
        {
            generatorType = FileNameGeneratorType.KeywordSequential;
            KeywordTextBox.Visible = true;
        }

        #endregion

        
    }
}
