﻿using System;
using System.Collections.Generic;
using System.IO;

namespace Text_File_Spawn_Utility
{
    class TextFile
    {
        private static char secondDelimiter = '-';

        public static IList<string> LoadTextFile(string inputFileFullPath, char delimiter)
        {
            List<string> spawnFiles = new List<string>();

            if (File.Exists(inputFileFullPath))
            {
                string line;
                string data = null;
                bool delimiterLineValid = false;
                bool secondDelimiterValid = false;

                using (System.IO.StreamReader file = new System.IO.StreamReader(inputFileFullPath))
                {
                    while ((line = file.ReadLine()) != null)
                    {
                        delimiterLineValid = Helpers.AllCharactersAreDelimiter(line, delimiter);
                        secondDelimiterValid = Helpers.AllCharactersAreDelimiter(line, secondDelimiter);

                        // do not include delimiters in output files
                        if (!delimiterLineValid && !secondDelimiterValid)    //!line.Equals(delimiter) && !line.Contains("---"))
                        {
                            data += line + System.Environment.NewLine;
                        }

                        // check for delimiter
                        if (delimiterLineValid || secondDelimiterValid)     //line.Equals(delimiter) || line.Contains("---"))
                        {
                            if (!string.IsNullOrWhiteSpace(data))
                            {
                                spawnFiles.Add(data);
                                data = string.Empty;
                            }
                        }
                    }

                    file.Close();
                }
            }

            return spawnFiles;
        }

        public static void CreateFiles(string outputFolder, IList<string> data, FileNameGeneratorType generatorType, string fileNameKeyword)
        {
            if (!Directory.Exists(outputFolder))
                return;

            string fileNameFormat = null;
            int fileIndex = 1;

            foreach (string item in data)
            {
                if (string.IsNullOrWhiteSpace(item))
                    continue;

                // generator type
                switch (generatorType)
                {
                    case FileNameGeneratorType.DateTimeMilliseconds:
                        fileNameFormat = string.Format("{0} {1} {2}.txt", DateTime.Now.ToLongDateString(), DateTime.Now.ToLongTimeString().Replace(":", "-"), fileIndex);
                        break;
                    case FileNameGeneratorType.KeywordSequential:
                        fileNameFormat = string.Format("{0} {1}.txt", fileNameKeyword, fileIndex);
                        break;
                }

                string fileName = fileNameFormat;
                fileName = Helpers.MakeValidFileName(fileName);
                string path = Path.Combine(outputFolder, fileName);

                WriteFile(path, item);

                fileIndex++;
            }
        }

        private static void WriteFile(string path, string data)
        {
            using (StreamWriter sw = new StreamWriter(path))
            {
                sw.Write(data);
                sw.Close();
            }
        }
    }
}
